@@ -7,7 +7,6 @@ from django.contrib.auth.forms import AuthenticationForm
 from django.contrib.sites.models import get_current_site
 from django.forms import Form
 from django.shortcuts import redirect
-from django.utils.translation import ugettext_lazy as _
 from django.views.decorators.cache import never_cache
 from django.views.generic import FormView, DeleteView, TemplateView
 from django_otp.decorators import otp_required
@@ -37,6 +36,7 @@ class LoginView(IdempotentSessionWizardView):
     condition_dict = {
         'token': lambda self: default_device(self.get_user()),
     }
+    redirect_field_name = REDIRECT_FIELD_NAME
 
     def __init__(self, **kwargs):
         super(LoginView, self).__init__(**kwargs)
@@ -53,14 +53,20 @@ class LoginView(IdempotentSessionWizardView):
         return super(LoginView, self).post(*args, **kwargs)
 
     def done(self, form_list, **kwargs):
+        """
+        Login the user and redirect to the desired page.
+        """
         login(self.request, self.get_user())
 
-        redirect_to = self.request.GET.get(REDIRECT_FIELD_NAME, '')
+        redirect_to = self.request.GET.get(self.redirect_field_name, '')
         if not is_safe_url(url=redirect_to, host=self.request.get_host()):
             redirect_to = str(settings.LOGIN_REDIRECT_URL)
         return redirect(redirect_to)
 
     def get_form_kwargs(self, step=None):
+        """
+        AuthenticationTokenForm requires the user kwarg.
+        """
         if step == 'token':
             return {
                 'user': self.get_user(),
@@ -68,6 +74,9 @@ class LoginView(IdempotentSessionWizardView):
         return {}
 
     def get_device(self):
+        """
+        Returns the OTP device selected by the user, or his default device.
+        """
         if not self.device_cache:
             challenge_device_id = self.request.POST.get('challenge_device', None)
             if challenge_device_id:
@@ -80,40 +89,34 @@ class LoginView(IdempotentSessionWizardView):
         return self.device_cache
 
     def render(self, form=None, **kwargs):
+        """
+        If the user selected a device, ask the device to generate a challenge;
+        either making a phone call or sending a text message.
+        """
         if self.steps.current == 'token':
             self.get_device().generate_challenge()
         return super(LoginView, self).render(form, **kwargs)
 
     def get_user(self):
+        """
+        Returns the user authenticated by the AuthenticationForm.
+        """
         if not self.user_cache:
             form_obj = self.get_form(step='auth',
-                                     data=self.storage.get_step_data('auth'),
-                                     files=self.storage.get_step_files('auth'))
+                                     data=self.storage.get_step_data('auth'))
             self.user_cache = form_obj.is_valid() and form_obj.user_cache
         return self.user_cache
 
     def get_context_data(self, form, **kwargs):
+        """
+        Adds user's default and backup OTP devices to the context.
+        """
         context = super(LoginView, self).get_context_data(form, **kwargs)
         if self.steps.current == 'token':
-            device = self.get_device()
-            context['device'] = device
-            if isinstance(device, PhoneDevice):
-                if device.method == 'call':
-                    context['instructions'] = _(
-                        'We are calling your phone right now, please enter '
-                        'the digits you hear.')
-                else:
-                    context['instructions'] = _(
-                        'We sent you a text message, please enter the tokens '
-                        'we sent.')
-            else:
-                context['instructions'] = _(
-                    'Please enter the tokens generated by your token '
-                    'generator.')
-
+            context['device'] = self.get_device()
             context['other_devices'] = [
                 phone for phone in backup_phones(self.get_user())
-                if phone != device]
+                if phone != self.get_device()]
         context['cancel_url'] = settings.LOGOUT_URL
         return context
 
@@ -224,15 +227,7 @@ class SetupView(IdempotentSessionWizardView):
                 'QR_URL': get_qr_url(alias, key)
             })
         elif self.steps.current == 'validation':
-            device = self.get_device()
-            if device.method == 'call':
-                context['instructions'] = _(
-                    'We are calling your phone right now, please enter '
-                    'the digits you hear.')
-            else:
-                context['instructions'] = _(
-                    'We sent you a text message, please enter the tokens '
-                    'we sent.')
+            context['device'] = self.get_device()
         context['cancel_url'] = settings.LOGIN_REDIRECT_URL
         return context
 
@@ -262,9 +257,13 @@ class BackupTokensView(FormView):
         return context
 
     def form_valid(self, form):
-        self.get_device().token_set.all().delete()
+        """
+        Delete existing backup codes and generate new ones.
+        """
+        device = self.get_device()
+        device.token_set.all().delete()
         for n in range(10):
-            self.get_device().token_set.create(token=StaticToken.random_token())
+            device.token_set.create(token=StaticToken.random_token())
 
         return redirect('two_factor:backup_tokens')
 
